@@ -1,3 +1,4 @@
+import urllib
 from datetime import datetime
 
 from sp_api.base import Client, Marketplaces, sp_endpoint, Granularity, ApiResponse
@@ -108,6 +109,8 @@ class Sales(Client):
         })
         if granularityTimeZone:
             kwargs.update({'granularityTimeZone': granularityTimeZone})
+        if 'sku' in kwargs:
+            kwargs.update({'sku': urllib.parse.quote_plus(kwargs.pop('sku'))})
         return self._request(kwargs.pop('path'), params=kwargs)
 
     @staticmethod
