@@ -1,5 +1,5 @@
-from sp_api.api import Notifications
-from sp_api.base import SellingApiException, NotificationType
+from sp_api.api import Notifications, Reports
+from sp_api.base import SellingApiException, NotificationType, ReportType
 
 
 def test_create_destination():
@@ -23,3 +23,4 @@ def test_get_subscriptions():
     res = Notifications().get_subscription(NotificationType.REPORT_PROCESSING_FINISHED)
     assert res.payload.get('destinationId') == 'TEST_CASE_200_DESTINATION_ID'
     assert res.payload.get('subscriptionId') == 'TEST_CASE_200_SUBSCRIPTION_ID'
+
